@@ -3,5 +3,8 @@ from .sites.energy import EnergySession
 from .sites.ids import IDSSession
 from .sites.rsbbs import RSBBSSession
 from .sites.wx import WXSession
+from .sites.xk import XKSession
 from .sites.zfw import ZFWSession
-from .sites.xk import XKSession
\ No newline at end of file
+from .sites.sports import SportsSession
+
+import libxduauth.utils.update
